==> kreetingkard-0.6.1.tar.gz: kreetingkard-0.6.1/src/kkaddressbook/kkatreeview.h <==
/***************************************************************************
 *   Copyright (C) 2005 by SUZUKI Tasuku                                   *
 *   tasuku@linux-life.net                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef _KKATREEVIEW_H_
#define _KKATREEVIEW_H_

#include <klistview.h>

#include <qdom.h>

class KActionCollection;

namespace KKAddressBook
{
	class KKAContactData;

	class KKATreeView : public KListView
	{
		Q_OBJECT
	public:
		KKATreeView( QWidget* parent = 0, const char* name = 0 );
		virtual ~KKATreeView();

		QPtrList<KKAContactData> printData();
	protected:
		KActionCollection* actionCollection();

	private slots:
		void readData();
		void saveData();
		void groupNew();
		void groupRename();
		void groupRemove();

	private:
		void createData( QDomDocument& doc );
	};
}

#endif /* _KKATREEVIEW_H_ */

==> kreetingkard-0.6.2.tar.gz: kreetingkard-0.6.2/src/kkaddressbook/kkatreeview.h <==
/***************************************************************************
 *   Copyright (C) 2005 by SUZUKI Tasuku                                   *
 *   tasuku@linux-life.net                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef _KKATREEVIEW_H_
#define _KKATREEVIEW_H_

#include <klistview.h>

#include <qdom.h>

class KActionCollection;

namespace KKAddressBook
{
	class KKAContactData;

	class KKATreeView : public KListView
	{
		Q_OBJECT
	public:
		KKATreeView( QWidget* parent = 0, const char* name = 0 );
		virtual ~KKATreeView();

		QPtrList<KKAContactData> printData();
		
	protected:
		KActionCollection* actionCollection();
		void contentsDragEnterEvent( QDragEnterEvent* event );
		void contentsDropEvent( QDropEvent* event );
		void contentsDragMoveEvent ( QDragMoveEvent* event );

	private slots:
		void readData();
		void saveData();
		void groupNew();
		void groupRename();
		void groupRemove();

	private:
		void createData( QDomDocument& doc );
	};
}

#endif /* _KKATREEVIEW_H_ */
